systemtools.StorageFormatManager
================================

.. autoclass:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager

Lineage
-------

.. graphviz::

   digraph InheritanceGraph {
       graph [background=transparent,
           color=lightslategrey,
           fontname=Arial,
           outputorder=edgesfirst,
           overlap=prism,
           penwidth=2,
           rankdir=LR,
           root="__builtin__.object",
           splines=spline,
           style="dotted, rounded"];
       node [colorscheme=pastel19,
           fontname=Arial,
           fontsize=12,
           penwidth=2,
           style="filled, rounded"];
       edge [color=lightsteelblue2,
           penwidth=2];
       subgraph cluster___builtin__ {
           graph [label=__builtin__];
           "__builtin__.object" [color=1,
               group=0,
               label=object,
               shape=box];
       }
       subgraph cluster_systemtools {
           graph [label=systemtools];
           "systemtools.StorageFormatManager" [color=black,
               fontcolor=white,
               group=1,
               label=<<B>StorageFormatManager</B>>,
               shape=box,
               style="filled, rounded"];
       }
       "__builtin__.object" -> "systemtools.StorageFormatManager";
   }

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.accepts_kwargs
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.compare
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.format_one_value
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_format_pieces
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_hash_values
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_import_statements
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_indentation_strings
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_input_argument_values
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_dictionary
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_names
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_values
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_dictionary
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_names
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_values
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_repr_format
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_root_package_name
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_signature_keyword_argument_names
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_signature_positional_argument_names
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_storage_format
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_tools_package_name
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_tools_package_qualified_class_name
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_types
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_unique_python_path_parts
      ~abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.is_instance

Bases
-----

- :py:class:`__builtin__.object <object>`

Static methods
--------------

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.accepts_kwargs
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.compare
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.format_one_value
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_format_pieces
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_hash_values
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_import_statements
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_indentation_strings
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_input_argument_values
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_dictionary
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_names
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_keyword_argument_values
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_dictionary
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_names
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_positional_argument_values
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_repr_format
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_root_package_name
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_signature_keyword_argument_names
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_signature_positional_argument_names
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_storage_format
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_tools_package_name
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_tools_package_qualified_class_name
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_types
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.get_unique_python_path_parts
   :noindex:

.. automethod:: abjad.tools.systemtools.StorageFormatManager.StorageFormatManager.is_instance
   :noindex:
